# -*- coding: cp1252 -*-
"""Common filenames and locations for topographic data, meshes and outputs.
"""

from os import sep, environ, getenv, getcwd ,umask
from os.path import expanduser
import sys
from time import localtime, strftime, gmtime
from anuga.utilities.polygon import read_polygon, plot_polygons, is_inside_polygon, number_mesh_triangles
#from anuga.coordinate_transforms.redfearn import degminsec2decimal_degrees, convert_points_from_latlon_to_utm
from anuga.utilities.system_tools import get_user_name, get_host_name
from anuga.shallow_water.data_manager import urs2sts,create_sts_boundary
from anuga.utilities.polygon import read_polygon, plot_polygons, polygon_area, is_inside_polygon

# file and system info
#---------------------------------

home = getenv('INUNDATIONHOME') + sep +'data'+sep #Sandpit's parent dir   
muxhome = getenv('MUXHOME')
user = get_user_name()
host = get_host_name()

# INUNDATIONHOME is the inundation directory, not the data directory.

#time stuff
time = strftime('%Y%m%d_%H%M%S',localtime()) #gets time for new dir
gtime = strftime('%Y%m%d_%H%M%S',gmtime()) #gets time for new dir
build_time = time+'_build'
run_time = time+'_run'
print 'gtime: ', gtime

#Making assumptions about the location of scenario data
state = 'western_australia'
scenario_name = 'geraldton'
scenario = 'geraldton_tsunami_scenario'


tide = 0.75 #??? must check!!!

alpha = 0.1
friction=0.01
starttime=0
finaltime=80000
export_cellsize=25
setup='final'
source='polyline'


if setup =='trial':
    print'trial'
    res_factor=10
    time_thinning=48
    yieldstep=240
if setup =='basic': 
    print'basic'
    res_factor=4
    time_thinning=12
    yieldstep=120
if setup =='final': 
    print'final'
    res_factor=1
    time_thinning=4
    yieldstep=60

dir_comment='_'+setup+'_'+str(tide)+'_'+str(source)+'_'+ 'alpha' +str(alpha)+'_'+str(user)


# onshore data provided by WA DLI
onshore_name = 'landgate_dem_clip' # original
island_name = 'dted_srtm_islands'

# AHO + DPI data
coast_name = 'XYcoastline_KVP'
offshore_name = 'Geraldton_bathymetry'
offshore_name1 = 'DPI_Data'
offshore_name2 = 'grid250'
offshore_name3 = 'Top_bathymetry'


#final topo name
combined_name ='geraldton_combined_elevation'
combined_name_small = 'geraldton_combined_elevation_small'

anuga_dir = home+state+sep+scenario+sep+'anuga'+sep

topographies_in_dir = home+state+sep+scenario+sep+'elevation_final'+sep+'points'+sep
topographies_dir = home+state+sep+scenario+sep+'anuga'+sep+'topographies'+sep

##input topo file location
onshore_in_dir_name = topographies_in_dir + onshore_name
island_in_dir_name = topographies_in_dir + island_name

coast_in_dir_name = topographies_in_dir + coast_name
offshore_in_dir_name = topographies_in_dir + offshore_name
offshore_in_dir_name1 = topographies_in_dir + offshore_name1
offshore_in_dir_name2 = topographies_in_dir + offshore_name2
offshore_in_dir_name3 = topographies_in_dir + offshore_name3

onshore_dir_name = topographies_dir + onshore_name
island_dir_name = topographies_dir + island_name
coast_dir_name = topographies_dir + coast_name
offshore_dir_name = topographies_dir + offshore_name
offshore_dir_name1 = topographies_dir + offshore_name1
offshore_dir_name2 = topographies_dir + offshore_name2
offshore_dir_name3 = topographies_dir + offshore_name3

#final topo files
combined_dir_name = topographies_dir + combined_name
combined_dir_name_small = topographies_dir + combined_name_small

meshes_dir = anuga_dir+'meshes'+sep
meshes_dir_name = meshes_dir + scenario_name

polygons_dir = anuga_dir+'polygons'+sep
tide_dir = anuga_dir+'tide_data'+sep

#boundaries_source = '1'

#boundaries locations
boundaries_dir = anuga_dir+'boundaries'+sep
boundaries_dir_name = boundaries_dir + scenario_name
boundaries_dir_mux = muxhome

#output locations
output_dir = anuga_dir+'outputs'+sep
output_build_time_dir = anuga_dir+'outputs'+sep+build_time+dir_comment+sep
output_run_time_dir = anuga_dir+'outputs'+sep+run_time+dir_comment+sep
output_run_time_dir_name = output_run_time_dir + scenario_name  #Used by post processing

vertex_filename = output_run_time_dir + 'mesh_vertex.csv'

#gauges
gauge_name = '???.csv'
gauges_dir = home+state+sep+scenario+sep+'anuga'+sep+'gauges'+sep
gauges_dir_name = gauges_dir + gauge_name

buildings_filename = gauges_dir + 'Busselton_res_Project.csv'
buildings_filename_out = 'Busselton_res_Project_modified.csv'

community_filename = gauges_dir +''
community_broome = gauges_dir + ''


###############################
# Interior region definitions
###############################

# bounding polygon for study area
poly_all = read_polygon(polygons_dir+'poly_all.csv')
res_poly_all = 100000*res_factor

poly_neg20_pos20 = read_polygon(polygons_dir+'neg20_pos20.csv')
res_neg20_pos20 = 20000*res_factor

poly_CBD_1km= read_polygon(polygons_dir+'CBD_1km.csv')
res_CBD_1km = 800*res_factor

poly_cbd = read_polygon(polygons_dir+'CBD_500m.csv')
res_cbd = 500*res_factor

poly_wallabi = read_polygon(polygons_dir+'island_wallabi_poly.csv')
res_wallabi = 1000*res_factor

poly_dingiville = read_polygon(polygons_dir+'island_dingiville_poly.csv')
res_dingiville = 1000*res_factor

poly_pelsaert = read_polygon(polygons_dir+'island_pelsaert_poly.csv')
res_pelsaert = 1000*res_factor


#plot_polygons([polyAll,poly_broome1,poly_broome2,poly_broome3],figname='boundingpoly2',verbose=False)

interior_regions = [[poly_neg20_pos20,res_neg20_pos20],[poly_CBD_1km,res_CBD_1km],
                    [poly_cbd,res_cbd],[poly_wallabi,res_wallabi],
                    [poly_dingiville,res_dingiville],[poly_pelsaert, res_pelsaert]]

trigs_min = number_mesh_triangles(interior_regions, poly_all, res_poly_all)
print 'min number triangles', trigs_min

poly_mainland=read_polygon(topographies_in_dir +'initial_condition.csv')

###################################################################
# Clipping regions for export to asc and regions for clipping data
###################################################################


# Geraldton CBD extract ascii grid
xminCBD = 262700
xmaxCBD = 267600
yminCBD = 6811500
ymaxCBD = 6816400

